==> funcoeszz_18.3.orig.tar.gz: funcoeszz-18.3/testador/zznerdcast.sh <==
$ zznerdcast | wc -l	#→ 45
$ zznerdcast -n 13 | wc -l	#→ 39
$ zznerdcast  -x 2	#→ --regex ^Uso:
$ zznerdcast  -d 4/3/2016
NerdCast 506 - Cegos, nerds e loucos 2 | 04 Mar 2016
https://nerdcast.jovemnerd.com.br/nerdcast_506_cegos_nerds_loucos_2.mp3

NerdTech 01 - Os buracos da tecnologia | 04 Mar 2016
https://nerdcast.jovemnerd.com.br/nerdtech_01.mp3

$ zznerdcast -m 03-2013
NerdCast 356 - Consultas, exames e check ups | 29 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_356_exames.mp3

NerdCast 355 - Eu só quero chocolate | 22 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_355_chocolate.mp3

NerdCast 354 - O turno dos RTS games | 15 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_354_RTS_games.mp3

NerdCast 353 - Coreia Style | 08 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_353_coreia.mp3

NerdCast 352 - A Ciência dos Super-Herois | 01 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_352_ciencia_herois.mp3

$ zznerdcast -- -H
NerdCast 490 - O Ultra-Humano | 05 Nov 2015
https://nerdcast.jovemnerd.com.br/nerdcast_490_ultra_humano.mp3

NerdCast 425 - A Ciência dos Super-Heróis 2 | 01 Aug 2014
https://nerdcast.jovemnerd.com.br/nerdcast_425_ciencia_herois_2.mp3

NerdCast 352 - A Ciência dos Super-Herois | 01 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_352_ciencia_herois.mp3

NerdCast 181 - Nerdcast para Não-Humanos | 02 Oct 2009
https://nerdcast.jovemnerd.com.br/nerdcast_181_alienigenas.mp3

NerdCast 22 - Super-Homem nos quadrinhos | 13 Jul 2006
https://nerdcast.jovemnerd.com.br/nerdcast_022_supermanHQ.mp3

NerdCast 01 - Super-Homem: Herói americano ou do mundo? | 02 Apr 2006
https://nerdcast.jovemnerd.com.br/001_SupermanReturns.mp3

$ zznerdcast HaloCast
HaloCast 3 - HaloCast 3 | 22 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_03.mp3

HaloCast 2 - HaloCast 2 | 17 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_02.mp3

HaloCast 1 - HaloCast 1 | 11 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_01.mp3

$ zznerdcast  Battlestar Galactica
NerdCast 235b - Battlestar Galactica – Deus ex Machina | 17 Nov 2010
https://nerdcast.jovemnerd.com.br/nerdcast_235b_battlestar_galactica.mp3

NerdCast 235a - Battlestar Galactica – Inteligência Artificial Emocional | 12 Nov 2010
https://nerdcast.jovemnerd.com.br/nerdcast_235a_battlestar_galactica.mp3

$ zznerdcast O Senhor dos Anéis
NerdCast 192c - O Senhor dos Anéis: O Retorno do Rei | 25 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192c_senhor_dos_aneis_3.mp3

NerdCast 192b - O Senhor dos Anéis: As Duas Torres | 22 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192b_senhor_dos_aneis_2.mp3

NerdCast 192a - O Senhor dos Anéis: A Sociedade do Anel | 18 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192a_senhor_dos_aneis_1.mp3

$ zznerdcast -a 2015 Empreendedor
Empreendedor 12 - A vida depois da venda | 18 Dec 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_12.mp3

Empreendedor 11 - O destino de uma empresa | 27 Nov 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_11.mp3

Empreendedor 10 - Expandindo o seu negócio | 30 Oct 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_10.mp3

Empreendedor 09 - Adaptar-se ou morrer | 25 Sep 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_09.mp3

Empreendedor 08 - Montando sua equipe | 28 Aug 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_08.mp3

Empreendedor 07 - De olho na oportunidade | 31 Jul 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_07.mp3

Empreendedor 06 - Empreendendo na crise | 26 Jun 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_06.mp3

NerdCast 470 - Expresso Empreendedor 5 | 19 Jun 2015
https://nerdcast.jovemnerd.com.br/nerdcast_470_expresso_empreendedor_05.mp3

Empreendedor 05 - Empresas e sustentabilidade | 29 May 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_05.mp3

Empreendedor 04 - A Gestão do Negócio | 24 Apr 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_04.mp3

Empreendedor 03 - O Plano de Negócios | 27 Mar 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_03.mp3

Empreendedor 02 - Abrindo a Empresa | 27 Feb 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_02.mp3

Empreendedor 01 - O Valor de Uma Ideia | 30 Jan 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_01.mp3

$

==> funcoeszz_21.1.orig.tar.gz: funcoeszz-21.1/testador/zznerdcast.sh <==
$ zznerdcast | wc -l	#=> 45
$ zznerdcast -n 13 | wc -l	#=> 39
$ zznerdcast  -x 2	#=> --regex ^Uso:
$ zznerdcast  -d 4/3/2016
NerdCast 506 - Cegos, nerds e loucos 2 | 04 Mar 2016
https://nerdcast.jovemnerd.com.br/nerdcast_506_cegos_nerds_loucos_2.mp3

NerdTech 01 - Os buracos da tecnologia | 04 Mar 2016
https://nerdcast.jovemnerd.com.br/nerdtech_01.mp3

$ zznerdcast -m 03-2013
NerdCast 356 - Consultas, exames e check ups | 29 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_356_exames.mp3

NerdCast 355 - Eu só quero chocolate | 22 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_355_chocolate.mp3

NerdCast 354 - O turno dos RTS games | 15 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_354_RTS_games.mp3

NerdCast 353 - Coreia Style | 08 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_353_coreia.mp3

NerdCast 352 - A Ciência dos Super-Herois | 01 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_352_ciencia_herois.mp3

$ zznerdcast -- -H
NerdCast 657 - A Ciência dos Super-Heróis 3 | 25 Jan 2019
https://nerdcast.jovemnerd.com.br/nerdcast_657_ciencia_dos_super_herois_3.mp3

NerdCast 490 - O Ultra-Humano | 05 Nov 2015
https://nerdcast.jovemnerd.com.br/nerdcast_490_ultra_humano.mp3

NerdCast 425 - A Ciência dos Super-Heróis 2 | 01 Aug 2014
https://nerdcast.jovemnerd.com.br/nerdcast_425_ciencia_herois_2.mp3

NerdCast 352 - A Ciência dos Super-Herois | 01 Mar 2013
https://nerdcast.jovemnerd.com.br/nerdcast_352_ciencia_herois.mp3

NerdCast 181 - Nerdcast para Não-Humanos | 02 Oct 2009
https://nerdcast.jovemnerd.com.br/nerdcast_181_alienigenas.mp3

NerdCast 22 - Super-Homem nos quadrinhos | 13 Jul 2006
https://nerdcast.jovemnerd.com.br/nerdcast_022_supermanHQ.mp3

NerdCast 01 - Super-Homem: Herói americano ou do mundo? | 02 Apr 2006
https://nerdcast.jovemnerd.com.br/001_SupermanReturns.mp3

$ zznerdcast HaloCast
HaloCast 3 - HaloCast 3 | 22 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_03.mp3

HaloCast 2 - HaloCast 2 | 17 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_02.mp3

HaloCast 1 - HaloCast 1 | 11 Dec 2015
https://nerdcast.jovemnerd.com.br/halocast_01.mp3

$ zznerdcast  Battlestar Galactica
NerdCast 235b - Battlestar Galactica – Deus ex Machina | 17 Nov 2010
https://nerdcast.jovemnerd.com.br/nerdcast_235b_battlestar_galactica.mp3

NerdCast 235a - Battlestar Galactica – Inteligência Artificial Emocional | 12 Nov 2010
https://nerdcast.jovemnerd.com.br/nerdcast_235a_battlestar_galactica.mp3

$ zznerdcast O Senhor dos Anéis
NerdCast 192c - O Senhor dos Anéis: O Retorno do Rei | 25 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192c_senhor_dos_aneis_3.mp3

NerdCast 192b - O Senhor dos Anéis: As Duas Torres | 22 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192b_senhor_dos_aneis_2.mp3

NerdCast 192a - O Senhor dos Anéis: A Sociedade do Anel | 18 Dec 2009
https://nerdcast.jovemnerd.com.br/nerdcast_192a_senhor_dos_aneis_1.mp3

$ zznerdcast -a 2015 Empreendedor
Empreendedor 12 - A vida depois da venda | 18 Dec 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_12.mp3

Empreendedor 11 - O destino de uma empresa | 27 Nov 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_11.mp3

Empreendedor 10 - Expandindo o seu negócio | 30 Oct 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_10.mp3

Empreendedor 09 - Adaptar-se ou morrer | 25 Sep 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_09.mp3

Empreendedor 08 - Montando sua equipe | 28 Aug 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_08.mp3

Empreendedor 07 - De olho na oportunidade | 31 Jul 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_07.mp3

Empreendedor 06 - Empreendendo na crise | 26 Jun 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_06.mp3

NerdCast 470 - Expresso Empreendedor 5 | 19 Jun 2015
https://nerdcast.jovemnerd.com.br/nerdcast_470_expresso_empreendedor_05.mp3

Empreendedor 05 - Empresas e sustentabilidade | 29 May 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_05.mp3

Empreendedor 04 - A Gestão do Negócio | 24 Apr 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_04.mp3

Empreendedor 03 - O Plano de Negócios | 27 Mar 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_03.mp3

Empreendedor 02 - Abrindo a Empresa | 27 Feb 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_02.mp3

Empreendedor 01 - O Valor de Uma Ideia | 30 Jan 2015
https://nerdcast.jovemnerd.com.br/nerdcast_empreendedor_01.mp3

$
